@@ -1,3 +1,3 @@
 from .base_client import BaseClient
 from .model import File
-from .utils import setup_storage, get_storage_client
+from .utils import get_storage_client, setup_storage
