@@ -52,7 +52,9 @@ def force_sync(fn):
     return wrapper
 
 
-def sizeof_fmt(num, suffix="B"):
+def sizeof_fmt(num: Optional[Any], suffix="B") -> str:
+    if num is None:
+        return ""
     for unit in ["", "K", "M", "G", "T", "P", "E", "Z"]:
         if abs(num) < 1024.0:
             return "%3.1f%s%s" % (num, unit, suffix)
