@@ -1,6 +1,8 @@
 from enum import Enum
 from typing import Optional, List, Union
+import pytz
 
+from pydantic import validator
 from fa_common import CamelModel
 
 # from fa_common.db import DocumentDBModel
@@ -37,6 +39,10 @@ class ScidraModule(CamelModel):
     input_schema: str = ""
     output_schema: str = ""
     input_files: List[FileFieldDescription] = []
+    cpu_limit: int = 4
+    cpu_request: int = 1
+    memory_limit_gb: int = 8
+    memory_request_gb: int = 2
 
 
 class JobRun(CamelModel):
@@ -48,6 +54,7 @@ class JobRun(CamelModel):
     name: Optional[str]
     stage: Optional[str]
     output: Optional[Union[List, dict]]
+    # output_files:
     log: Optional[bytes]
 
 
@@ -88,3 +95,10 @@ class WorkflowProject(CamelModel):
     user_id: str
     gitlab_project_id: int
     created: Optional[str]
+    timezone: str = "UTC"
+
+    @validator("timezone")
+    def must_be_valid_timezone(cls, v):
+        if v not in pytz.all_timezones:
+            raise ValueError(f"{v} is not a valid timezone")
+        return v
